#
# spec file for package gle-graphics
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gle-graphics
Version:        4.2.4c
Release:        6.21
Summary:        GLE is a graphics scripting language
License:        BSD-3-Clause
Group:          Productivity/Graphics/Visualization/Graph
Url:            http://www.gle-graphics.org/
Source:         http://prdownloads.sourceforge.net/glx/gle-graphics-%{version}f-src.tar.gz
Source1:        gle.vim
#Source2:    GLE-4.0.13-manual.pdf
Source3:        GLEusersguide.pdf
Source4:        makeani.pl
Source5:        bbox_gle.sh
Source6:        %{name}.xml
Source7:        qgle.desktop
Source1000:     gle-graphics-rpmlintrc
# PATCH-UPSTREAM: needs for build with gcc4.4 - was sent to upstream
Patch0:         gle-graphics-gcc44.patch
Patch1:         string-gledir.patch
Patch2:         string-gledir-filemenu.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  c++_compiler
BuildRequires:  cairo-devel
BuildRequires:  dos2unix
BuildRequires:  ghostscript-library
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt4-devel
BuildRequires:  libtiff-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  shared-mime-info
BuildRequires:  texlive-latex
BuildRequires:  pkgconfig(glu)
%if %suse_version > 1220
BuildRequires:  texlive-amsfonts
BuildRequires:  texlive-cm-super
BuildRequires:  texlive-dvips
BuildRequires:  texlive-makeindex
BuildRequires:  texlive-pdftex
BuildRequires:  tex(fancyvrb.sty)
BuildRequires:  tex(pdftex.def)
BuildRequires:  tex(rotating.sty)
BuildRequires:  tex(supertabular.sty)
%endif
BuildRequires:  unzip
BuildRequires:  xorg-x11-libs

%if %defined suse_version
BuildRequires:  update-desktop-files
%endif

Requires:       ghostscript
Requires:       lib%{name} = %{version}
Requires:       perl

# The old libgle-graphics package
Provides:       libgle-graphics = %{version}
Obsoletes:      libgle-graphics < %{version}
Provides:       libgle-graphics-4_1_1 = %{version}
Obsoletes:      libgle-graphics-4_1_1 < %{version}
Provides:       libgle-graphics-4_2_0 = %{version}
Obsoletes:      libgle-graphics-4_2_0 < %{version}

%if %defined suse_version
Suggests:       LaTeX
%endif

%description
GLE (Graphics Layout Engine) is a graphics scripting language designed for
creating publication quality graphs, plots, diagrams, figures and slides. GLE
supports various graph types (function plots, histograms, bar graphs, scatter
plots, contour lines, color maps, surface plots, ...) through a simple but
flexible set of graphing commands. More complex output can be created by
relying on GLE's scripting language, which is full featured with subroutines,
variables, and logic control. GLE relies on LaTeX for text output and supports
mathematical formulea in graphs and figures. GLE's output formats include EPS,
PS, PDF, JPEG, and PNG. GLE is licenced under the BSD license.

A suggested dependency is a LaTeX package.

%package -n qgle

Summary:        User interface for %{name}
License:        GPL-2.0
Group:          Productivity/Graphics/Visualization/Graph
Requires:       %{name} = %{version}

%description -n qgle
QGLE, the GLE user interface, is licenced under the GPL license.

%package doc

Summary:        Documentation for %{name}
License:        BSD-3-Clause
Group:          Documentation/Other

%description doc
User guide and reference manual for GLE

%prep
%setup -q

%patch0 -b .gcc44
%patch1 -p0
%patch2 -p0

cp %{SOURCE3} .

# wrong end of line encoding
dos2unix \
        gle-refman/utilities/fig/volcano.z \
        gle-refman/advanced/fig/join.gle \
        gle-refman/primitives/fig/gc_arrstyle.gle \
        gle-refman/appendix/fig/color_sample.gle \
        gle-refman/graph/fig/gc_loglabels.gle \
        gle-refman/prog/fig/axisformat.gle \
        src/samples/sample_compare.eps \
        src/samples/qgle_keyboard.gle 

for mk in $(find -name 'Makefile*.in') ; do
    if ! grep -q '^CXXFLAGS=@CXXFLAGS@' $mk ; then
	sed -ri 's/^(CXX=@CXX@)/\1 %optflags/' $mk
    fi
done
(cat >> src/gui/qgle.pro.in)<<-'EOF'
	unix {
	    QMAKE_CXXFLAGS += %optflags
	    QMAKE_CFLAGS += %optflags
	}
	EOF

%build
%{configure} \
  --with-extrafonts 
#make %{?_smp_mflags}
make 
make doc

cd src/samples/
make -f Makefile.gcc
find . -type 'd' -iname '.gle' | xargs rm -rf
rm Makefile.{os2,vc}
cd ..

%install
make DESTDIR=%{buildroot} install

rm -f %{buildroot}/%{_libdir}/pkgconfig/%{name}.pc
# will be handled via %doc in filelist
rm -rf %{buildroot}/%{_datadir}/doc/%{name}/

# vim syntax file
install -d -m755 %{buildroot}/%{_datadir}/vim/site/syntax/
install -m644 %{SOURCE1} %{buildroot}/%{_datadir}/vim/site/syntax/

# tools
install -d -m755 %{buildroot}/%{_bindir}
install -m755 %{SOURCE4} %{SOURCE5} %{buildroot}/%{_bindir}

# mime type
install -d -m 755 %{buildroot}%{_datadir}/mime/application
install -m 644 %{SOURCE6} %{buildroot}%{_datadir}/mime/application/%{name}.xml

# icon
install -d -m755 %{buildroot}/%{_datadir}/pixmaps/
install -m644 src/gui/images/gle.png %{buildroot}/%{_datadir}/pixmaps/qgle.png

# menu
%if %defined suse_version
%suse_update_desktop_file -i qgle
%endif

%post -n qgle
%mime_database_post

%postun -n qgle
%mime_database_postun

%files
%defattr(-,root,root,0755)
%doc README.txt LICENSE.txt
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/%{version}
%dir %{_datadir}/%{name}/%{version}/font
%dir %{_datadir}/%{name}/%{version}/gleinc
%{_bindir}/gle
%{_bindir}/glebtool
%{_bindir}/manip
%{_bindir}/makeani.pl
%{_bindir}/bbox_gle.sh
%{_datadir}/%{name}/%{version}/font/*
%{_datadir}/%{name}/%{version}/gleinc/*
%{_datadir}/%{name}/%{version}/glerc
%{_datadir}/vim/
%{_datadir}/%{name}/%{version}/init.tex
%{_datadir}/%{name}/%{version}/inittex.ini
%{_datadir}/%{name}/%{version}/manip.hlp
%{_mandir}/man1/gle.1.gz
%{_libdir}/libgle-graphics-%{version}.so

%files -n qgle
%defattr(-,root,root,0755)
%{_bindir}/qgle
%{_datadir}/applications/*
%{_datadir}/pixmaps/qgle.png
%{_datadir}/mime/application/%{name}.xml

%files doc
%defattr(-,root,root,0755)
%doc GLEusersguide.pdf gle-refman/gle-manual.pdf
%doc src/samples/

%changelog
* Thu Jul  2 2015 tjcw@physics.org
- Fix build break re string.class and accessing it as a 'char *'
  * string-gledir.patch
  * string-gledir-filemenu.patch
* Sat Jun 27 2015 tjcw@physics.org
- do string properly
* Mon Jan 12 2015 mvyskocil@opensuse.org
- Update to 4.2.3c, bugfix release
  * see ChangeLog.txt for more details
- obsoleted gle-graphics-gcc47.patch, already upstream
- obsoleted overflow.patch, already upstream
* Tue Oct  1 2013 dimstar@opensuse.org
- Be precise with the mime configuration:
  + Add shared-mime-info BuildRequires
  + Only own the mime specifying xml file, not the directory
    structure.
  + Replace 'manual' /usr/bin/update-mime-database calls with
    %%mime_database_post/postun scrtiptlets provided by
    shared-mime-info.
  + Move the mime_database_post/postun to the qgle subpackage,
    which is in fact the package installing the mime handlers and
    the mime definition.
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit glu dependency
* Tue Jul 24 2012 werner@suse.de
- Add missing fonts
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
* Mon Jul  9 2012 werner@suse.de
- Avoid some overflows
* Thu Jun 28 2012 werner@suse.de
- apply RPM_OPT_FLAGS
* Sat Mar 17 2012 zaitor@opensuse.org
- Add gle-graphics-gcc47.patch: Fix build with gcc 4.7.
* Thu Feb  2 2012 dlovasko@suse.com
- update to 4.2.4b
  * Added GLU dependency to make GLE compile with Qt4.8
  * Fixed bug in fallback to "texcmr" when using -cairo
  * Fixed crash due to subroutine argument type mismatch
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Mon Sep 12 2011 mvyskocil@suse.cz
- use QMAKE_LIBS_DYNLOAD in qgle.pro.in
* Mon Apr 18 2011 mvyskocil@suse.cz
- update to 4.2.3b a bugfix release mainly in qgle
  * Experimental support for EMF output (the vector format on Windows).
- move from Contrib to Factory
* Wed Jan  6 2010 mvyskocil@suse.cz
- update to 4.2.2 a bugfix release
- removed manip tool
- include libgle.so into main package
- used changes
* Tue Apr 14 2009 mvyskocil@suse.cz
- update to 4.2.0
- removed pkgconfig file from packaging
- used %%%%{configure} for build
- removed stripping patch (Patch0)
- build documentation (samples, gle-refman)
- add a libgle-graphics provides to library subpackage
- install a vim macro into vim/site instead of vim/current
- fixed dependencies
* Thu Mar 12 2009 mvyskocil@suse.cz
- fixed a build under gcc4.4
* Mon Dec 15 2008 mvyskocil@suse.cz
- fixed a 'directories not owned by a package'
* Fri Sep 19 2008 mvyskocil@suse.cz
- fix of bad stripping
- split the library to extra package (according the Shared Library Policy)
- changed groups
- removed the old Obsoletes
- remove of rm -rf $RPM_BUILD_ROOT in prep
- the docdir is now a _defaultdocdir
- add an examples in documentation
- used a %%%%doc than a manual installation
- renamed -manual to -doc
- corrected end of line encoding in bbox_gle.sh
* Fri Jan  4 2008 mvyskocil@suse.cz
- updated to 4.1.1, which contains the upstream patches
- Smooth option of "dn line" fixed for log-scale graphs (Bug #1860761).
- Patches to make GLE compile with gcc 4.3 (by Michal Vyskocil).
- Patches to make GLE work on 64 bit machines with "lib64" dir (by Michal Vyskocil).
- Tried to fix GhostScript problem in QGLE on 64 bit machines
- some several changes
- removed the latex subpackage, becasue the init.tex file is necessary and gle don't work
  without him
- added the bbox_gle.sh and a makeani.pl tools
- added the desktop file and a mime type file
* Wed Jan  2 2008 mvyskocil@suse.cz
- fix the library path for dlopen in x86_64
* Wed Jan  2 2008 mvyskocil@suse.cz
- correct a libdir install path (necessary for x86_64)
* Sun Dec 30 2007 mvyskocil@suse.cz
- first release in openSUSE
